@@ -23,9 +23,11 @@
 #include <math.h>
 #include <getopt.h>
 
-#define VERSION "1.2"
+#define VERSION "1.3"
 #define max(A,B) ( (A) > (B) ? (A):(B))
 #define min(A,B) ( (A) > (B) ? (B):(A))
+#define who_play(i) ((i % 12) / 6)   //Return the player (0 ou 1) of hole i.
+#define who_wait(i) (1-(i % 12) / 6) //Return the opponent (0 ou 1) of hole i.
 
 struct option longopts[] = {
   {"help", no_argument, NULL, 'h'},
@@ -38,8 +40,9 @@ struct option longopts[] = {
   {"depth", required_argument, NULL, 'd'},
   {"level", required_argument, NULL, 'l'},
   {"eat", required_argument, NULL, 'e'},
-  {"noeatmore", no_argument, NULL, 'n'},
+  {"noeatmore", no_argument, NULL, 'm'},
   {"noeatall", no_argument, NULL, 'a'},
+  {"noattackall", no_argument, NULL, 'k'},
   {"single", no_argument, NULL, 's'},
   {"hint", no_argument, NULL, 'i'},
   {"xawale", no_argument, NULL, 'x'},
@@ -47,14 +50,14 @@ struct option longopts[] = {
 };
 
 static char *progname;
-int flagh = 0, flagv = 0, flagr = 0, flagb = 0, flago = 0, flagc = 0, flagp = 0;
-int flagd = 0, flagl = 0, flage = 0, flagn = 0, flaga = 0, flags = 0, flagi = 0;
-int flagx = 0, lose = 0;
-int depth = 9;                    // initial depth for the min-max algorithm
-int level = 0;                    // level of game
-int neh = 4;                      // max number of eaten holes
-int computer = 1, human = 0;
-double tmax[3] = {2, 20, 100};
+int flagh = 0, flagv = 0, flagr = 0, flagb = 0, flago = 0, flagc = 0;
+int flagp = 0, flagd = 0, flagl = 0, flage = 0, flagm = 0, flaga = 0;
+int flagk = 0, flags = 0, flagi = 0, flagx = 0, lose = 0;
+int depth = 9;                // initial depth of the min-max algorithm
+int level = 0;                // level of game
+int neh = 4;                  // max number of eaten holes
+int computer = 1, human = 0;  // computer plays top line (1) by default
+double tmax[3] = {2, 20, 100};// max cpu time of levels 1 to 3
 
 int
 main (int argc, char *argv[])
@@ -67,15 +70,15 @@ main (int argc, char *argv[])
   int distribute (int *, int *, int, char *);
   int hole[12] = { 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4 };
   int score[2] = { 0, 0 };
-  char label[4] = "RUN";
+  char label[4] = "BEG";
   int i, j, del[12], val[12], move = -1;
-  char r[64];
+  char response[64];
 
   
   progname = argv[0];
 
   while ((optc =
-	  getopt_long (argc, argv, "hvrb:o:c:p:d:l:e:nasix", longopts,
+	  getopt_long (argc, argv, "hvrb:o:c:p:d:l:e:maksix", longopts,
 		       (int *) 0)) != -1)
     switch (optc)
       {
@@ -127,7 +130,6 @@ main (int argc, char *argv[])
 	move--;
 	human    = who_play (move);
 	computer = who_wait (move);
-	strcpy(label,"BEG");
 	break;
       case 'd':
 	flagd = 1;
@@ -155,9 +157,12 @@ main (int argc, char *argv[])
 	  }
 	level--;
 	break;
-      case 'n':
-	flagn = 1;
+      case 'm':
+	flagm = 1;
 	break;
+	  case 'k':
+    flagk = 1;
+    break;
       case 'a':
         flaga = 1;
         break;
@@ -197,7 +202,7 @@ main (int argc, char *argv[])
   -r, --rule      display rules of awale\n\n\
   -b BOARD, --board=BOARD\n\
                   start with BOARD. BOARD is a string of type\n\
-                  h1-h2- ... h12 where hi is the number of stones in hole i\n\
+                  h1-h2- ... h12 where hi is the number of seeds in hole i\n\
   -o SCORE, --score=SCORE\n\
                   start with SCORE. SCORE is a string of type\n\
                   s1-s2 where sj is the score of player j\n\
@@ -208,8 +213,9 @@ main (int argc, char *argv[])
   -d N, --depth=N  initial depth N of the algorithm (default N=9)\n\
   -l L, --level=L level L=1, 2 or 3 of game (default L=1)\n\
   -e E, --eat=E   maximum number of holes which can be eaten (default E=4)\n\
-  -n, --noeatmore eat nothing when trying to eat more than E holes\n\
-  -a, --noeatall  eat nothing when trying to eat all remaining stones\n\
+  -m, --noeatmore eat nothing when trying to eat more than E holes\n\
+  -a, --noeatall  eat nothing when trying to eat all remaining seeds\n\
+  -k, --noattackall forbiden to attack all the opponent seeds\n\
   -s, --single    process a single move\n\
   -i, --hint      print hints\n\
   -x  --xawale    start in engine mode. A single line output is provided at\n\
@@ -241,27 +247,27 @@ For more information about these matters, see the file named COPYING.\n");
     {
       printf ("Rules of awale.\n\n\
 Awale game contains two lines of six holes. Each player plays a single line.\n\n\
-Every holes contain four stones at the beginning of the game.\n\n\
+Every holes contain four seeds at the beginning of the game.\n\n\
 One plays alternately. One never play two turns, one cannot pass his turn.\n\n\
-When playing, take all the stones of a hole in your line and distribute it\n\
-in successive holes turning counterclock wise, one stone per hole. Do not\n\
-put a stone in the starting hole (this case arrives when the starting hole\n\
-contains more than twelve stones.)\n\n\
-The stones of the arrival hole are eaten when the arrival hole lies in the\n\
-opponent line and contains two or three stones (after all stones are distri-\n\
+When playing, take all the seeds of a hole in your line and distribute it\n\
+in successive holes turning counterclock wise, one seed per hole. Do not\n\
+put a seed in the starting hole (this case arrives when the starting hole\n\
+contains more than twelve seeds.)\n\n\
+The seeds of the arrival hole are eaten when the arrival hole lies in the\n\
+opponent line and contains two or three seeds (after all seeds are distri-\n\
 buted). All contiguous previous holes which meet this condition are also\n\
 eaten. It is possible to eat a maximum of four holes, when five holes are\n\
 eatable, only the last four ones are eaten.\n\n\
-Players have to play such that the opponent always has at least one stone.\n\
+Players have to play such that the opponent always has at least one seed.\n\
 In case it is impossible, the game stops.\n\n\
-The winner is the player who has eaten the most stones.\n");
+The winner is the player who has eaten the most seeds.\n");
 
       exit (0);
     }
 
 
 
-/* incompatible options -y and -o */
+/* incompatible options -c and -p */
   if (flagc && flagp)
     {
       fprintf (stderr, "%s: Incompatible flags: -c and -p\n", progname);
@@ -277,9 +283,9 @@ The winner is the player who has eaten the most stones.\n");
       do
         {
           printf("Game level <1-3> ");
-          scanf ("%s", r);
+          scanf ("%s", response);
 	}
-      while (sscanf (r, "%d", &level) != 1 || level < 1 || level > 3);
+      while (sscanf (response, "%d", &level) != 1 || level < 1 || level > 3);
       level--;                            // level ranges from 0 to 2
      }
 
@@ -288,9 +294,9 @@ The winner is the player who has eaten the most stones.\n");
       do
         {
           printf("Begin <1> or no <0> ");
-          scanf ("%s", r);
+          scanf ("%s", response);
 	}
-      while (sscanf (r, "%d", &flagp) != 1 || flagp < 0 || flagp > 1);
+      while (sscanf (response, "%d", &flagp) != 1 || flagp < 0 || flagp > 1);
 
     
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
@@ -300,38 +306,48 @@ The winner is the player who has eaten the most stones.\n");
   if (!flagx)
     print_board (hole, score, 0, label);
 
-  if (flagp)
-    {
-      move = ask_move (hole, move, label);
-      if (valid (hole, move))
-	distribute (hole, score, move, label);
-      else
-	strcpy (label, "ERR");
-      print_board (hole, score, move, label);
-      if (!strcmp (label, "END") || !strcmp (label, "ERR") || flags)
-	exit_game (label);
-    }
-
   do
     {
-      move = best_move (hole, score, label);
-      distribute (hole, score, move, label);
-      print_board (hole, score, move, label);
-      if (!strcmp (label, "END") || flags)
-	break;
-	
-      move = ask_move (hole, move, label);
-      distribute (hole, score, move, label);
-      print_board (hole, score, move, label);
-      if (!strcmp (label, "END"))
-	break;
+    
+      if (!flagp || strcmp(label, "BEG"))
+        {
+         move = best_move (hole, score, label);
+         distribute (hole, score, move, label);
+         print_board (hole, score, move, label);
+         if (!strcmp (label, "END") || flags) exit_game (label);
+        }
+        
+      do
+        {
+          move = ask_move (hole, move, label);
+          if (strcmp(label, "ERR"))
+            distribute (hole, score, move, label);
+          print_board (hole, score, move, label);
+         }
+       while (!strcmp(label, "ERR") && !flags);
+       if (!strcmp (label, "END") || flags) exit_game (label);
 
     }
   while (1);
 
-  exit_game (label);
 }
 
+
+/*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+! Exit message.
+!ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
+
+void
+exit_game (char * label)
+{
+  if (!flagx)
+    {
+      printf ("Bye\n");
+    }
+  exit (0);
+}
+
+
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 ! Ask for a move and return the move.
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
@@ -343,7 +359,7 @@ ask_move (int hole[], int move, char* label)
   void exit_game (char *);
   char r[64];
 
-  if (!strcmp(label,"BEG"))
+  if (!strcmp(label,"BEG") && flagp && move != -1)
     {
       if (!flagx)
         printf ("Your move is: %d\n", move+1);
@@ -356,13 +372,22 @@ ask_move (int hole[], int move, char* label)
             printf ("Your move is: ");
           scanf ("%s", r);
           if (!strcmp (r, "quit") || !strcmp (r, "exit") || !strcmp (r, "stop") || !strcmp (r, "q"))
-    	  exit_game (label);
+    	    exit_game (label);
         }
-      while (sscanf (r, "%d", &move) != 1 || move < (human * 6 + 1)
-          || move > (human * 6 + 6) || !valid (hole, move - 1));
+      while (sscanf (r, "%d", &move) != 1 || move < (human * 6 + 1) || move > (human * 6 + 6));
       move--;
     }
      
+  if (!valid (hole, move)) 
+    {
+     strcpy(label, "ERR");
+     if (!flagx) printf("Invalid move\n");
+    }
+  else
+    {
+     strcpy(label, "RUN");
+    }
+  
   return move;
 
 }
@@ -444,22 +469,6 @@ best_move (int hole[], int score[], char *label)
 
 }
 
-/*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-! Exit message.
-!ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
-
-void
-exit_game (char * label)
-{
-  if (!flagx)
-    {
-      if (!strcmp(label,"ERR"))
-        printf("Invalid move. ");
-      printf ("Bye\n");
-    }
-  exit (0);
-}
-
 
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 ! Output board and score.
@@ -524,85 +533,80 @@ print_board (int hole[], int score[], int move, char *label)
       if (!strcmp (label, "END"))
 	{
 	  if (score[human] > score[computer])
-	    printf ("Tu m'as bien gagne\n");
+	    printf ("You win\n");
 	  else if (score[computer] > score[human])
-	    printf ("Je t'ai bien gagne\n");
+	    printf ("You lose\n");
 	  else
-	    printf ("C'est meme score\n");
+	    printf ("It's a draw\n");
 	}
     }
 }
 
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-! Distribution of stones.
-! Return 1 if the game is still running and 0 if the game 
-! is ended.
+! Distribution of seeds.
+! Return 1 if the game is running, 0 if the game is over.
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
 
 int
 distribute (int hole[], int score[], int i, char *label)
 {
   int end_game (int *, int *, int);
-  int who_play (int), who_wait (int);
   int player, other;
-  int n, i0, i1, j, jj, j0, j1, nt;
+  int n, i0, i1, j, j0, j1, na, ne;
 
   player = who_play (i);
   other = who_wait (i);
 
-/* distribution of stones */
+/* distribution of seeds */
 
   n = hole[i];
   hole[i] = 0;
-
-  j = 0;
-  do
+  j = i;
+  while (n > 0)
     {
-      j++;
-      if (j % 12 == 0)
-	n++;
-      else
-	{
-	  jj = (i + j) % 12;
-	  hole[jj]++;
-	}
+      j = (j+1) % 12;
+      if (j != i)
+        {
+         hole[j]++;
+	     n--;
+        }
     }
-  while (j < n);
+  j1=j;                 // j1 is the last hole reached
+  
+/* attacked holes */
+
+  na = 0;
+  while (j >= 0 && j / 6 == other && (hole[j] == 2 || hole[j] == 3))
+    {
+      j--;
+      na++; 
+    }                   // na is the number of attacked holes
 
 /* score calculation */
 
-  j1=jj;                // j1 is the last hole reached
-  nt = 1;
-  while (jj / 6 != player && (hole[jj] == 2 || hole[jj] == 3))
-    {
-      jj = (jj - 1 + 12) % 12;
-      nt++;
-    }
-  nt--;                 // nt is the number of eatable holes 
-
-  if (flagn == 0 || nt <= neh)
+  if (flagm == 0 || na <= neh)
     {
 
-     j0=j1-min(nt,neh); // eaten holes run from j0+1 to j1
+     j0=j1-min(na,neh); // eaten holes run from j0+1 to j1
 
      if (flaga) 
        {
-        for (i0=other*6, i1=i0+6, jj=i0; jj<i1; jj++) 
-          {
-           if ((jj<=j0 || jj>j1) && hole[jj]!=0) break;
-          }
-       }                // all stones of the opponent are eaten when jj=i1
+        for (ne=0, i0=other*6, i1=i0+6, j=i0; j<i1; j++)
+           if (hole[j]!=0) ne++; // ne is the number of non-empty holes    
+       }
 
-     if (!flaga || jj!=i1)
+     if (!flaga || min(na,neh)!=ne)
        {
-        for (jj=j1; jj>j0; jj--)
+        for (j=j1; j>j0; j--)
           {
-           score[player] = score[player] + hole[jj];
-           hole[jj] = 0;
+           score[player] = score[player] + hole[j];
+           hole[j] = 0;
           }             // score is updated
        }
     }
 
+/* update label */
+
   if (end_game (hole, score, i))
     {
       strcpy (label, "END");
@@ -624,14 +628,13 @@ distribute (int hole[], int score[], int i, char *label)
 int
 end_game (int hole[], int score[], int i)
 {
-  int who_play (int), who_wait (int);
   int player, other;
   int j, i0, i1, n;
 
   player = who_play (i);
   other = who_wait (i);
 
-/* the opponent has no stone */
+/* the opponent has no seed */
 
   i0 = player * 6;
   i1 = other * 6;
@@ -644,7 +647,7 @@ end_game (int hole[], int score[], int i)
       return 1;
     }
 
-/* the player has no stone and the opponent doesn't provide stone */
+/* the player has no seed and the opponent doesn't provide seed */
 
   n = (2 - player) * 6;
 
@@ -682,15 +685,15 @@ end_game (int hole[], int score[], int i)
 int
 valid (int hole[], int i)
 {
-  int who_play (int), who_wait (int);
+  int all_is_attacked (int *, int);
   int i0, i1;
 
-/* no stone in hole i */
+/* no seed in hole i */
 
   if (hole[i] == 0)
     return 0;
 
-/* the opponent has no stone and the player doesn't provide stone */
+/* the opponent has no seed and the player doesn't provide seed */
 
   i0 = who_play (i) * 6;
   i1 = who_wait (i) * 6;
@@ -700,6 +703,16 @@ valid (int hole[], int i)
       && (i + hole[i]) <= i0 + 5)
     return 0;
 
+/* the player attacks all opponent seeds although it is not necessary */
+
+  if (flagk && all_is_attacked(hole,i   ) && 
+     (!all_is_attacked(hole,i0  ) || !all_is_attacked(hole,i0+1) || 
+      !all_is_attacked(hole,i0+2) || !all_is_attacked(hole,i0+3) || 
+      !all_is_attacked(hole,i0+4) || !all_is_attacked(hole,i0+5)))
+    {
+     return 0;
+    }
+
 /* the move is valid */
 
   return 1;
@@ -707,23 +720,62 @@ valid (int hole[], int i)
 }
 
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-! Return the player (0 ou 1) of hole i.
+! Return 1 if all opponent seeds are attacked by move i.
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
 
 int
-who_play (int i)
+all_is_attacked (int hole2[], int i)
 {
-  return (i % 12) / 6;
-}
+  int hole[12];
+  int player, other;
+  int n, i0, i1, j, na, ne;
 
-/*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-! Return the opponent (0 ou 1) of hole i.
-!ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
+  if (hole2[i] == 0) return 1; // return 1 if the hole i is empty
+  
+  for (j = 0; j <= 11; j++)
+    hole[j] = hole2[j];
+    
+//  player = who_play (i);
+  other = who_wait (i);
+  
+/* Alternative algorithm for distribution
+  n = i+hole[i]+hole[i]/12;
+  for (j = i+1; j <= n; j++)
+     hole[j%12]++;
+  hole[i] = 0;
+  j1=n%12;             // j1 is the last seed reached
+  j=j1; */
+  
+  n = hole[i];         // distribution of seeds
+  hole[i] = 0;
+  j = i;
+  while (n > 0)
+   {
+    j = (j+1) % 12;
+    if (j != i)
+      {
+       hole[j]++;
+       n--;
+      }
+    }                 // j is the last hole reached
 
-int
-who_wait (int i)
-{
-  return 1 - (i % 12) / 6;
+  na = 0;
+  while (j >= 0 && j / 6 == other && (hole[j] == 2 || hole[j] == 3))
+    {
+     j--;
+     na++;            // na is the number of attacked holes 
+    }
+    
+  if (na >= 0 && na <= neh)
+    {
+     for (ne=0, i0=other*6, i1=i0+6, j=i0; j<i1; j++)
+        if (hole[j]!=0) ne++;
+     if (na == ne)
+        return 1;     // ne is the number of non-empty holes
+    }
+    
+  return 0;
+    
 }
 
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
@@ -736,7 +788,6 @@ int
 value (int hole2[], int score2[], int i, int p)
 {
   int valid (int *, int);
-  int who_play (int), who_wait (int);
   int distribute (int *, int *, int, char *);
 
   int hole[12];
@@ -771,14 +822,13 @@ value (int hole2[], int score2[], int i, int p)
 }
 
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-! Return the largest delay before providing stones
+! Return the largest delay before providing seeds
 ! beginning with move i.
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
 
 int
 delay (int hole2[], int score2[], int i)
 {
-  int who_play (int), who_wait (int);
   int distribute (int *, int *, int, char *);
   int hole[12];
   int score[2];
