@@ -16,6 +16,8 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
 #  USA
 #
+# Version 1.3 last modified on May 6th, 2008.
+#
 #!/bin/bash
 # start wish \
 exec wish "$0" ${1+"$@"}
@@ -26,6 +28,7 @@ exec wish "$0" ${1+"$@"}
 
 proc copyrightDialog {first} {
 global BIN
+destroy .copyright
 set img [image create photo -file [file join $BIN copyright.gif]]
 toplevel .copyright -borderwidth 1 -relief sunken
 label .copyright.image -image $img
@@ -46,6 +49,7 @@ global trou gain label start
 global level depth depth0
 global turn iturn
 
+      set label "RUN"
 
       for {set i 0} {$i<12} {incr i} {
        set trou($i) 4
@@ -53,27 +57,102 @@ global turn iturn
 
       set gain(0) 0
       set gain(1) 0
-      
+
       set depth $depth0($level)
 
-      if {$start=="PLAYER"} {set label "RUN"} else {set label "BEG"}
+#      if {$start=="PLAYER"} {set label "RUN"} else {set label "BEG"}
 
       set iturn 0
       set turn(0) "board=4-4-4-4-4-4-4-4-4-4-4-4 score=0-0 move=0 $label"
 
-      if {$label=="BEG"} {jouer 0 1 1 4}
-      
+      affichage NULL
+      if {$start=="COMPUTER"} {jouer 0 1 1 4}
+
 }
 
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#                     Chose a file to import
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+
+proc importGame {} {
+global PATH LANG IFIL EFIL
+global level depth start
+global trou gain label
+global turn iturn
+
+set resu [tk_getOpenFile -parent . -title $IFIL($LANG) -initialdir [file join $PATH]]
+if {$resu!=""} {set file $resu} else {return 0}
+if {[catch {open $resu r} fid]} {tk_messageBox -message "$EFIL($LANG) $resu"; return}
+set iturn -1
+set depth [expr 7+$level]
+while {[gets $fid turn([incr iturn])]>0} {
+  scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
+                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
+                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
+  gain(0) gain(1) mvt label
+}
+incr iturn -1
+close $fid
+affichage NULL
+if {$start=="COMPUTER"&&$label=="RUN"} {jouer 0 1 1 4}
+}
+
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#                      Chose a file to save
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+
+proc saveGame {} {
+global PATH LANG SFIL EFIL
+global turn iturn
+set resu [tk_getSaveFile -parent . -title $SFIL($LANG) -initialdir [file join $PATH]]
+if {$resu!=""} {set file $resu} else {return 0}
+if {[catch {open $resu w} fid]} {tk_messageBox -message "$EFIL($LANG) $resu"; return}
+for {set jturn 0} {$jturn<=$iturn} {incr jturn} {puts $fid $turn($jturn)}
+close $fid
+}
+
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#                     Open configure file
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+
+proc openConf {} {
+global PATH LANG
+
+if {![catch {open [file join ~ .xawale.ini] r} fid]} {
+gets $fid line
+scan $line "LANG=%2s" LANG
+close $fid
+}
+
+}
+
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#                      Save configure file
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+
+proc saveConf {} {
+global PATH LANG
+
+if {![catch {open [file join ~ .xawale.ini] w} fid]} {
+puts $fid LANG=$LANG
+close $fid
+}
+
+}
 
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 #                     Undo : cancel a turn
+# Last modified 5 may 2008
+# the line
+#  if {$label=="RUN"&$iturn>=2} {
+# has been replaced by
+#  if {$iturn>=2} {
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc undo {} {
 global trou gain label
 global turn iturn
-if {$label=="RUN"&$iturn>=2} {
+if {$iturn>=2} {
 incr iturn -2
 scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
                 trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
@@ -163,6 +242,8 @@ set mvtcircle [.cnv create oval [expr 21+$b*5] [expr 94] [expr 21+$b*5+$a] [expr
 after 1000 ".cnv delete $mvtcircle"
 }
 
+update
+
 # fin de partie
 if {$label=="END"} {
   if {$gain(0)>$gain(1)} {
@@ -183,8 +264,8 @@ if {$label=="END"} {
 
 proc jouer {x y w h} {
 global BIN JOUER
-global level depth Tmin Tmax nbeat noeat noall
-global trou gain label
+global level depth Tmin Tmax nbeat noeat noall noatk
+global trou gain label start
 global turn iturn
 
 set ligne [format %.0f [expr floor(4*$y/$h)]]
@@ -193,83 +274,67 @@ if {$ligne==1} {set trou0 [expr 12-$colon]}
 if {$ligne==2} {set trou0 [expr $colon+1]}
 if {$ligne!=1&$ligne!=2} {return}
 
-if {$level!="2players"} {
-if {$label=="BEG"} {
-affichage NULL
 .cnv configure -cursor watch
 update
-set turn([incr iturn]) [exec $JOUER \
- -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
- -o $gain(0)-$gain(1) -c 2 -d $depth -e $nbeat -sx$noeat$noall]
+
+# player move
+if {$level!="2players"&&$ligne==2&&$label=="RUN"||$level=="2players"&&$label=="RUN"} {
+
+  set turn([incr iturn]) [exec $JOUER \
+    -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
+    -o $gain(0)-$gain(1) -p $trou0 -e $nbeat -sx$noeat$noall$noatk]
+  scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
+                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
+                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
+                gain(0) gain(1) mvt label
+  if {[cyclic]==1&&$label!="ERR"} {set label "END"}
+  if {$label=="ERR"} {incr iturn -1}
+  affichage $mvt
+
+}
+
+# computer move
+if {$level!="2players"&&$ligne==2&&$label=="RUN"||$level!="2players"&&$label=="RUN"&&$start=="COMPUTER"} {
+
+  set time0 [clock seconds]
+  set turn([incr iturn]) [exec $JOUER \
+    -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
+    -o $gain(0)-$gain(1) -c 2 -d $depth -e $nbeat -sx$noeat$noall$noatk]
+  scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
+                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
+                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
+                gain(0) gain(1) mvt label
+  set time [expr [clock seconds]-$time0]
+  if {$time==0}            {after 1000}
+  if {$time>$Tmax($level)} {incr depth -1}
+  if {$time<$Tmin($level)} {incr depth  1}
+  if {[cyclic]==1&&$label!="ERR"} {set label "END"}
+  if {$label=="ERR"} {incr iturn -1}
+  affichage $mvt
+
+}
+
 .cnv configure -cursor top_left_arrow
-scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
-#.cnv configure -cursor top_left_arrow
-affichage $mvt
+if {$label=="ERR"} {set label "RUN"}
 }
 
-if {$ligne==2&$label=="RUN"} {
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#                        Cyclic
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
-.cnv configure -cursor watch
-update
-set turn([incr iturn]) [exec $JOUER \
--b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
--o $gain(0)-$gain(1) -p $trou0 -e $nbeat -sx$noeat$noall]
-scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
-.cnv configure -cursor top_left_arrow
-affichage $mvt
-if {$label=="RUN"} {}
-if {$label=="ERR"} {set label "RUN"; return}
-if {$label=="END"} {return}
+proc cyclic {} {
+global trou gain label
+global turn iturn
 
-set time0 [clock seconds]
-.cnv configure -cursor watch
-update
-set turn([incr iturn]) [exec $JOUER \
--b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
--o $gain(0)-$gain(1) -c 2 -d $depth -e $nbeat -sx$noeat$noall]
-.cnv configure -cursor top_left_arrow
-set time [expr [clock seconds]-$time0]
-if {$time==0}            {after 1000}
-if {$time>$Tmax($level)} {incr depth -1}
-if {$time<$Tmin($level)} {incr depth  1}
-scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
-affichage $mvt
-}
+set n [string first " score" turn($iturn)]
 
-
-} else {
-
-
-if {$label=="RUN"} {
-
-update
-set turn([incr iturn]) [exec $JOUER \
--b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
--o $gain(0)-$gain(1) -p $trou0 -e $nbeat -sx$noeat$noall]
-scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
-affichage NULL
-if {$label=="RUN"} {}
-if {$label=="ERR"} {set label "RUN"; return}
-if {$label=="END"} {return}
+for {set i 1} {$i<$iturn} {incr i} {
+  if {[string compare -length $n $turn($i) $turn($iturn)]==0} {return 1}
 }
 
+return 0
 
 }
-}
-
-
 
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 #                   Display the content of a hole
@@ -283,70 +348,31 @@ set ligne [format %.0f [expr floor(4*$y/$h)]]
 set colon [format %.0f [expr floor(6*$x/$w)]]
 
 if {$ligne==0&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$gain(1) stone(s)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$gain(1) seed(s)"]"
 }
 
 if {$ligne==1&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou([expr 11-$colon]) stone(s)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou([expr 11-$colon]) seed(s)"]"
 }
 
 if {$ligne==2&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou($colon) stone(s)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou($colon) seed(s)"]"
 }
 
 if {$ligne==3&$label=="RUN"} {
-   after 2000 ".cnv delete [.cnv create text 38 70 -text "$gain(0) stone(s)"]"
+   after 2000 ".cnv delete [.cnv create text 38 70 -text "$gain(0) seed(s)"]"
 }
 
 
 }
 
-
-#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-#                     Chose a file to import
-#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-
-proc importGame {} {
-global PATH LANG IFIL EFIL
-global level depth
-global trou gain label
-global turn iturn
-set resu [tk_getOpenFile -parent . -title $IFIL($LANG) -initialdir [file join $PATH]]
-if {$resu!=""} {set file $resu} else {return 0}
-if {[catch {open $resu r} fid]} {tk_messageBox -message "$EFIL($LANG) $resu"; return}
-set iturn -1
-set depth [expr 7+$level]
-while {[gets $fid turn([incr iturn])]>0} {
-  scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-  gain(0) gain(1) mvt label
-}
-incr iturn -1
-close $fid
-affichage NULL
-}
-
-#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-#                      Chose a file to save
-#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-
-proc saveGame {} {
-global PATH LANG SFIL EFIL
-global turn iturn
-set resu [tk_getSaveFile -parent . -title $SFIL($LANG) -initialdir [file join $PATH]]
-if {$resu!=""} {set file $resu} else {return 0}
-if {[catch {open $resu w} fid]} {tk_messageBox -message "$EFIL($LANG) $resu"; return}
-for {set jturn 0} {$jturn<=$iturn} {incr jturn} {puts $fid $turn($jturn)}
-close $fid
-}
-
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 #                       Configure rules
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc configureRules {} {
-global BIN LANG MAXI EATL EATN EATA NOAL YES NO OK DEFA DETA nbeat noeat noall
+global BIN LANG MAXI EATL EATN EATA NOAL ATKA NOAK YES NO OK DEFA DETA nbeat noeat noall noatk
+destroy .configure
 toplevel .configure -borderwidth 1 -relief sunken
 
 labelframe .configure.frame1 -text $DETA($LANG) -labelanchor nw -padx 10 -borderwidth 2
@@ -376,7 +402,7 @@ pack   .configure.frame1.eat.lbl.2 -side top -anchor w
 
 frame  .configure.frame1.eat.chk
 radiobutton .configure.frame1.eat.chk.1 -variable noeat -value ""
-radiobutton .configure.frame1.eat.chk.2 -variable noeat -value "n"
+radiobutton .configure.frame1.eat.chk.2 -variable noeat -value "m"
 pack   .configure.frame1.eat.chk.1 -side top
 pack   .configure.frame1.eat.chk.2 -side top
 
@@ -393,13 +419,27 @@ radiobutton .configure.frame1.all.chk.2 -variable noall -value "a"
 pack   .configure.frame1.all.chk.1 -side top
 pack   .configure.frame1.all.chk.2 -side top
 
+frame  .configure.frame1.atk -borderwidth 10
+frame  .configure.frame1.atk.lbl
+label  .configure.frame1.atk.lbl.1 -text $ATKA($LANG)
+label  .configure.frame1.atk.lbl.2 -text $NOAK($LANG)
+pack   .configure.frame1.atk.lbl.1 -side top -anchor w
+pack   .configure.frame1.atk.lbl.2 -side top -anchor w
+
+frame  .configure.frame1.atk.chk
+radiobutton .configure.frame1.atk.chk.1 -variable noatk -value ""
+radiobutton .configure.frame1.atk.chk.2 -variable noatk -value "k"
+pack   .configure.frame1.atk.chk.1 -side top
+pack   .configure.frame1.atk.chk.2 -side top
+
 frame  .configure.button
 button .configure.button.ok      -text $OK($LANG)   -command {destroy .configure}
 button .configure.button.default -text $DEFA($LANG) -command {
-                                                           global noeat nbeat noall
+                                                           global noeat nbeat noall noatk
                                                            set noeat ""
                                                            set nbeat 4
                                                            set noall ""
+                                                           set noatk ""
                                                           }
 #button .configure.button.cancel -text "CANCEL" -command {destroy .configure}
 pack .configure.button.ok      -side left  -ipadx 18 -padx 5 -pady 5
@@ -415,6 +455,9 @@ pack .configure.frame1.eat.chk -side left  -anchor w
 pack .configure.frame1.all     -side top   -anchor w
 pack .configure.frame1.all.lbl -side left  -anchor w
 pack .configure.frame1.all.chk -side left  -anchor w
+pack .configure.frame1.atk     -side top   -anchor w
+pack .configure.frame1.atk.lbl -side left  -anchor w
+pack .configure.frame1.atk.chk -side left  -anchor w
 pack .configure.button -side bottom -anchor s
 
 }
@@ -425,6 +468,7 @@ pack .configure.button -side bottom -anchor s
 
 proc helpDialog {} {
 global BIN LANG
+destroy .rule
 toplevel .rule -borderwidth 1 -relief sunken
 set flag_uk [image create photo -file [file join $BIN uk.gif]]
 set flag_fr [image create photo -file [file join $BIN fr.gif]]
@@ -453,28 +497,28 @@ proc rule_sp {} {
 
 El juego del awale se compone de dos lneas de seis agujeros. La lnea de arriba se atribuye \
 al ordenador mientras que la lnea de abajo se atribuye al jugador. Los otros agujeros sirven \
-para almacenar la piedras comidas durante la partida.
+para almacenar la semillas comidas durante la partida.
 
-Cada agujero contiene cuatro piedras al principio de la partida.
+Cada agujero contiene cuatro semillas al principio de la partida.
 
 Los jugadores juegan cada uno su turno. No se puede jugar dos veces seguidas. No se puede \
 saltar su turno.
 
-El jugador que juega coge todas las piedras de uno de sus agujeros y las distribuye una a \
+El jugador que juega coge todas las semillas de uno de sus agujeros y las distribuye una a \
 una en cada uno de los agujeros siguientes en el sentido contrario a un reloj. No se ponen \
-piedras en el agujero inicial (ese caso se encuentra cuando el jugador distribuye ms de \
-doce piedras).
+semillas en el agujero inicial (ese caso se encuentra cuando el jugador distribuye ms de \
+doce semillas).
 
-Se comen las piedras del ltimo agujero al que se llega cuando este est situado en el \
-campo adverso y contiene dos o tres piedras contando la ltima piedra puesta. Se comen \
+Se comen las semillas del ltimo agujero al que se llega cuando este est situado en el \
+campo adverso y contiene dos o tres semillas contando la ltima semilla puesta. Se comen \
 tambin los agujeros consecutivos precedentes que responden a esta condicin. No se pueden \
 comer ms de cuatro agujeros consecutivos. Solo se comen los cuatro ltimos agujeros cuando \
 cinco agujeros o ms se pueden comer.
 
-El jugador tiene entonces que dar piedras al adversario cuando no le quedan ms a este. \
-Si no puede dar ms piedras, la partida se para.
+El jugador tiene entonces que dar semillas al adversario cuando no le quedan ms a este. \
+Si no puede dar ms semillas, la partida se para.
 
-El jugador que ha comido ms piedras ha ganado.
+El jugador que ha comido ms semillas ha ganado.
 }
 }
 
@@ -485,26 +529,26 @@ proc rule_fr {} {
 
 Le jeu d'awal se dcompose en deux lignes de six trous. La ligne du haut est affecte \
 l'ordinateur tandis que la ligne du bas est affecte au joueur. Les autres trous servent  stocker \
-les pierres "manges" au cours de la partie.
+les graines "manges" au cours de la partie.
 
-Chaque trou contient quatre pierres en dbut de partie.
+Chaque trou contient quatre graines en dbut de partie.
 
 Les joueurs jouent chacun leur tour. On ne peut pas jouer deux fois de suite. On ne peut pas sauter son tour.
 
-Le joueur qui joue prend toutes les pierres de l'un de ses trous et les distribue une  une \
-dans les trous suivants en tournant dans le sens anti-horaire. On ne pose pas de pierre \
+Le joueur qui joue prend toutes les graines de l'un de ses trous et les distribue une  une \
+dans les trous suivants en tournant dans le sens anti-horaire. On ne pose pas de graine \
 dans le trou de dpart (ce cas de figure se prsente lorsque le joueur distribue plus de douze \
-pierres).
+graines).
 
-On "mange" les pierres du dernier trou atteint lorsque celui se situe chez l'adversaire et contient deux ou trois pierres \
-en comptant la dernire pierre pose. On "mange" aussi les trous conscutifs prcdents qui respectent \
+On "mange" les graines du dernier trou atteint lorsque celui se situe chez l'adversaire et contient deux ou trois graines \
+en comptant la dernire graine pose. On "mange" aussi les trous conscutifs prcdents qui respectent \
 cette condition. On ne peut pas "manger" plus de quatre trous conscutifs. Seuls les quatre derniers trous sont \
 "mangs" lorsque cinq trous ou plus sont "mangeables".
 
-Le joueur est tenu de fournir des pierres  l'adversaire lorsque celui-ci n'en possde plus. \
-S'il ne peut pas fournir de pierres, la partie s'arrte.
+Le joueur est tenu de fournir des graines  l'adversaire lorsque celui-ci n'en possde plus. \
+S'il ne peut pas fournir de graines, la partie s'arrte.
 
-Le joueur qui a "mang" le plus de pierres a gagn.
+Le joueur qui a "mang" le plus de graines a gagn.
 }
 }
 
@@ -515,27 +559,27 @@ proc rule_uk {} {
 
 Awale game contains two lines of six holes. Each player plays a single line, the \
 upper line for the computer and the lower line for the player. Other pair of holes \
-are used for eaten stones.
+are used for eaten seeds.
 
-Every holes contain four stones at the beginning of the game.
+Every holes contain four seeds at the beginning of the game.
 
 One plays alternately. One never play two turns, one cannot pass his turn.
 
-When playing, take all the stones of a hole in your line and distribute it \
-in successive holes turning counterclock wise, one stone per hole. Do not \
-put a stone in the starting hole (this case arrives when the starting hole \
-contains more than twelve stones.)
+When playing, take all the seeds of a hole in your line and distribute it \
+in successive holes turning counterclock wise, one seed per hole. Do not \
+put a seed in the starting hole (this case arrives when the starting hole \
+contains more than twelve seeds.)
 
-The stones of the arrival hole are eaten when the arrival hole lies in the \
-opponent line and contains two or three stones (after all stones are distributed). \
+The seeds of the arrival hole are eaten when the arrival hole lies in the \
+opponent line and contains two or three seeds (after all seeds are distributed). \
 All contiguous previous holes which meet this condition are also \
 eaten. It is possible to eat a maximum of four holes, when five holes are \
 eatable, only the last four ones are eaten.
 
-Players have to play such that the opponent always has at least one stone. \
+Players have to play such that the opponent always has at least one seed. \
 In case it is impossible, the game stops.
 
-The winner is the player who has eaten the most stones.
+The winner is the player who has eaten the most seeds.
 }
 }
 
@@ -555,16 +599,16 @@ global label
 .menu.play entryconfigure  4 -label $QUIT($LANG)
 .menu entryconfigure  1 -label $PARA($LANG)
 .menu.para entryconfigure  0 -label $LEVE($LANG)
-#.menu.para.level entryconfigure  0 -label $TWOP($LANG)
-.menu.para.level entryconfigure  0 -label "$OPPO($LANG) 0"
-.menu.para.level entryconfigure  1 -label "$OPPO($LANG) 1"
-.menu.para.level entryconfigure  2 -label "$OPPO($LANG) 2"
-.menu.para.level entryconfigure  3 -label "$OPPO($LANG) 3"
+.menu.para.level entryconfigure  0 -label $TWOP($LANG)
+.menu.para.level entryconfigure  1 -label "$OPPO($LANG) 0"
+.menu.para.level entryconfigure  2 -label "$OPPO($LANG) 1"
+.menu.para.level entryconfigure  3 -label "$OPPO($LANG) 2"
+.menu.para.level entryconfigure  4 -label "$OPPO($LANG) 3"
 .menu.para entryconfigure  1 -label $STAR($LANG)
 .menu.para.start entryconfigure  0 -label $BOTT($LANG)
 .menu.para.start entryconfigure  1 -label $TOP($LANG)
-#.menu.para entryconfigure  2 -label $CONF($LANG)
-.menu.para entryconfigure  3 -label $LING($LANG)
+.menu.para entryconfigure  3 -label $CONF($LANG)
+.menu.para entryconfigure  2 -label $LING($LANG)
 .menu.para.lang entryconfigure 0 -label $UK($LANG)
 .menu.para.lang entryconfigure 1 -label $FR($LANG)
 .menu.para.lang entryconfigure 2 -label $SP($LANG)
@@ -573,7 +617,6 @@ global label
 .menu.help entryconfigure  1 -label $ABOU($LANG)
 
 if {$label=="BEG"|$label=="RUN"} {affichage NULL}
-
 }
 
 
@@ -604,6 +647,7 @@ set start PLAYER
 set nbeat 4
 set noeat ""
 set noall ""
+set noatk ""
 set label END
 for {set i 0} {$i<12} {incr i} {set idtrou($i) 0}
 set iturn 0
@@ -655,12 +699,18 @@ array set EATL [list uk "Eat the last holes when trying to eat more than the max
 array set EATN [list uk "Eat nothing when trying to eat more than the maximum"\
                      fr "Ne mange rien lorsqu'on dpasse le maximum"\
                      sp "No come nada cuando se pasa del mximo"]
-array set EATA [list uk "Possible to eat all opponent stones"\
-                     fr "Possibilit de manger toutes les pierres adverses"\
+array set EATA [list uk "Possible to eat all opponent seeds"\
+                     fr "Possibilit de manger toutes les graines adverses"\
                      sp "Se puede comer todos los agujeros del adversario"]
-array set NOAL [list uk "Eat nothing when trying to eat all opponent stones"\
-                     fr "Ne mange rien lorsqu'on attaque toutes les pierres adverses"\
-                     sp "No come nada cuando se intenta comer todas las piedras adversas"]
+array set NOAL [list uk "Eat nothing when trying to eat all opponent seeds"\
+                     fr "Ne mange rien lorsqu'on attaque toutes les graines adverses"\
+                     sp "No come nada cuando se intenta comer todas las semillas adversas"]
+array set ATKA [list uk "Allow to play a move which attacks all opponent seeds"\
+                     fr "Possibilit d'attaquer toutes les graines adverses"\
+                     sp "Se puede atacar todos los agujeros del adversario"]
+array set NOAK [list uk "Forbidden to play a move which attacks all opponent seeds"\
+                     fr "Interdiction d'attaquer toutes les graines adverses"\
+                     sp "No se puede atacar todas las semillas adversas"]
 array set IFIL [list uk "Select file to import" \
                      fr "Choisir le fichier  importer" \
                      sp "Elegir el fichero para importar"]
@@ -671,7 +721,7 @@ array set EFIL [list uk "ERROR when opening file" \
                      fr "ERREUR lors de l'ouverture du fichier" \
                      sp "ERROR cuando se abre el fichero"]
 
-
+openConf
 
 wm title . "Awale"
 
@@ -682,12 +732,12 @@ menu .menu -tearoff 0
 set m .menu.play
 menu $m -tearoff 0
 .menu add cascade -label $PLAY($LANG) -menu $m -underline 0
-$m add command -label $NEW($LANG)  -accelerator Crtl+N -command {initGame; affichage NULL}
+$m add command -label $NEW($LANG)  -accelerator Crtl+N -command {initGame}
 $m add command -label $OPEN($LANG) -accelerator Crtl+O -command {importGame}
 $m add command -label $SAVE($LANG) -accelerator Crtl+S -command {saveGame}
 $m add command -label $UNDO($LANG) -accelerator Crtl+Z -command {undo}
-$m add command -label $QUIT($LANG) -accelerator Crtl+Q -command {destroy .}
-bind . <Control-n> {initGame; affichage NULL}
+$m add command -label $QUIT($LANG) -accelerator Crtl+Q -command {saveConf; destroy .}
+bind . <Control-n> {initGame}
 bind . <Control-o> {importGame}
 bind . <Control-s> {saveGame}
 bind . <Control-z> {undo}
@@ -699,7 +749,7 @@ menu $m -tearoff 0
 .menu add cascade -label $PARA($LANG) -menu $m -underline 0
 $m add cascade -label $LEVE($LANG) -menu $m.level
 menu $m.level -tearoff 0
-#$m.level add radio -label "$TWOP($LANG)"   -variable level -value "2players"
+$m.level add radio -label "$TWOP($LANG)"   -variable level -value "2players"
 $m.level add radio -label "$OPPO($LANG) 0" -variable level -value 0 \
                                            -command "set depth $depth0(0)"
 $m.level add radio -label "$OPPO($LANG) 1" -variable level -value 1
@@ -709,12 +759,12 @@ $m add cascade -label $STAR($LANG) -menu $m.start
 menu $m.start -tearoff 0
 $m.start add radio -label $BOTT($LANG) -variable start -value "PLAYER"
 $m.start add radio -label $TOP($LANG)  -variable start -value "COMPUTER"
-#$m add command -label $CONF($LANG) -command {configureRules}
 $m add cascade -label $LING($LANG) -menu $m.lang
 menu $m.lang -tearoff 0
 $m.lang add radio -label $UK($LANG) -variable LANG -value "uk" -command {changeLang}
 $m.lang add radio -label $FR($LANG) -variable LANG -value "fr" -command {changeLang}
 $m.lang add radio -label $SP($LANG) -variable LANG -value "sp" -command {changeLang}
+$m add command -label $CONF($LANG) -command {configureRules}
 
 set m .menu.help
 menu $m -tearoff 0
